==> philib-0.3.0-sources.jar: ch/bind/philib/validation/ValidationUtil.java <==
/*
 * Copyright (c) 2006-2011 Philipp Meinen <philipp@bind.ch>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package ch.bind.philib.validation;

import java.util.Collection;

/**
 * TODO
 * 
 * @author Philipp Meinen
 */
public final class ValidationUtil {

	private ValidationUtil() {
	}

	public static final ValidationResults validate(final Validatable validatable) {
		final ValidationResults results = new ValidationResults();
		validatable.validate(results); // NPE is intended!
		return results;
	}

	public static final <T extends Validatable> ValidationResults validate(final Collection<T> validatables) {
		final ValidationResults results = new ValidationResults();
		for (Validatable validatable : validatables) {
			validatable.validate(results); // NPE is intended!
		}
		return results;
	}

	public static final <T extends Validatable> ValidationResults validate(final T[] validatables) {
		final ValidationResults results = new ValidationResults();
		for (Validatable validatable : validatables) {
			validatable.validate(results); // NPE is intended!
		}
		return results;
	}
}

==> philib-0.4.0-sources.jar: ch/bind/philib/validation/ValidationUtil.java <==
/*
 * Copyright (c) 2006-2011 Philipp Meinen <philipp@bind.ch>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package ch.bind.philib.validation;

import java.util.Collection;

/**
 * TODO
 * 
 * @author Philipp Meinen
 */
public final class ValidationUtil {

	private ValidationUtil() {}

	public static final ValidationResults validate(final Validatable validatable) {
		final ValidationResults results = new ValidationResults();
		validatable.validate(results); // NPE is intended!
		return results;
	}

	public static final <T extends Validatable> ValidationResults validate(final Collection<T> validatables) {
		final ValidationResults results = new ValidationResults();
		for (Validatable validatable : validatables) {
			validatable.validate(results); // NPE is intended!
		}
		return results;
	}

	public static final <T extends Validatable> ValidationResults validate(final T[] validatables) {
		final ValidationResults results = new ValidationResults();
		for (Validatable validatable : validatables) {
			validatable.validate(results); // NPE is intended!
		}
		return results;
	}
}
